-- Host: localhost    Database: ipplan
---------------------------------------------------------

--
-- Table structure for table 'area'
--

CREATE TABLE area (
  areaaddr bigint NOT NULL default '0',
  descrip varchar(80) NOT NULL default '',
  areaindex serial,
  customer smallint NOT NULL default '0',
  PRIMARY KEY (areaindex),
  UNIQUE (customer,descrip),
  UNIQUE (areaaddr,customer)
);

--
-- Table structure for table 'auditlog'
--

CREATE TABLE auditlog (
  action varchar(80) NOT NULL default '',
  dt timestamp
);
CREATE INDEX auditlog_dt ON auditlog (dt);

--
-- Table structure for table 'base'
--

CREATE TABLE base (
  baseaddr bigint NOT NULL default '0',
  subnetsize int NOT NULL default '0',
  descrip varchar(80) NOT NULL default '',
  baseindex serial,
  admingrp varchar(40) NOT NULL default '',
  customer smallint NOT NULL default '0',
  lastmod timestamp,
  userid varchar(40) NOT NULL default '',
  swipmod timestamp,
  PRIMARY KEY  (baseindex),
  UNIQUE (baseaddr,customer)
);
CREATE INDEX base_customer ON base (customer);
CREATE INDEX base_admingrp ON base (admingrp);

--
-- Table structure for table 'custinfo'
--

CREATE TABLE custinfo (
  customer smallint NOT NULL default '0',
  org varchar(100) NOT NULL default '',
  street varchar(255) NOT NULL default '',
  city varchar(80) NOT NULL default '',
  state char(2) NOT NULL default '',
  zipcode varchar(10) NOT NULL default '',
  cntry char(2) NOT NULL default '',
  maint varchar(80) NOT NULL default '',
  nichandl varchar(80) NOT NULL default '',
  lname varchar(80) NOT NULL default '',
  fname varchar(80) NOT NULL default '',
  mname varchar(80) NOT NULL default '',
  torg varchar(100) NOT NULL default '',
  tstreet varchar(255) NOT NULL default '',
  tcity varchar(80) NOT NULL default '',
  tstate char(2) NOT NULL default '',
  tzipcode varchar(10) NOT NULL default '',
  tcntry char(2) NOT NULL default '',
  phne varchar(20) NOT NULL default '',
  mbox varchar(100) NOT NULL default '',
  PRIMARY KEY  (customer)
);

--
-- Table structure for table 'customer'
--

CREATE TABLE customer (
  custdescrip varchar(80) NOT NULL default '',
  customer serial,
  admingrp varchar(40) NOT NULL default '',
  PRIMARY KEY  (customer),
  UNIQUE (custdescrip)
);
CREATE INDEX customer_admingrp ON customer (admingrp);

--
-- Table structure for table 'grp'
--

CREATE TABLE grp (
  grpdescrip varchar(80) NOT NULL default '',
  grp varchar(40) NOT NULL default '',
  grpopt int NOT NULL default '0',
  createcust char(1) NOT NULL default 'N',
  PRIMARY KEY  (grp)
);
CREATE INDEX grp_grpdescrip ON grp (grpdescrip);

--
-- Table structure for table 'ipaddr'
--

CREATE TABLE ipaddr (
  ipaddr bigint NOT NULL default '0',
  userinf varchar(80) NOT NULL default '',
  location varchar(80) NOT NULL default '',
  telno varchar(15) NOT NULL default '',
  descrip varchar(80) NOT NULL default '',
  baseindex int NOT NULL default '0',
  lastmod timestamp NOT NULL,
  userid varchar(40) NOT NULL default '',
  PRIMARY KEY  (ipaddr,baseindex)
);
CREATE INDEX ipaddr_baseindex ON ipaddr (baseindex);

--
-- Table structure for table 'range'
--

CREATE TABLE range (
  rangeaddr bigint NOT NULL default '0',
  rangesize int NOT NULL default '0',
  descrip varchar(80) NOT NULL default '',
  rangeindex serial,
  areaindex int NOT NULL default '0',
  customer smallint NOT NULL default '0',
  PRIMARY KEY  (rangeindex),
  UNIQUE (rangeaddr,customer),
  UNIQUE (customer,descrip)
);
CREATE INDEX range_areaindex ON range (areaindex);

--
-- Table structure for table 'revdns'
--

CREATE TABLE revdns (
  customer smallint NOT NULL default '0',
  hname varchar(100) NOT NULL default '',
  ipaddr varchar(15) NOT NULL default '',
  horder smallint NOT NULL default '0'
);
CREATE INDEX revdns_customer ON revdns (customer);

--
-- Table structure for table 'schema'
--

CREATE TABLE schema (
  version int default NULL
);

BEGIN;
INSERT INTO schema (version) VALUES (6);
COMMIT;

--
-- Table structure for table 'users'
--

CREATE TABLE users (
  userid varchar(40) NOT NULL default '',
  userdescrip varchar(80) NOT NULL default '',
  password varchar(40) NOT NULL default '',
  PRIMARY KEY  (userid)
);

--
-- Table structure for table 'usergrp'
--

CREATE TABLE usergrp (
  userid varchar(40) NOT NULL default '',
  grp varchar(40) NOT NULL default '',
  UNIQUE (userid,grp)
);
CREATE INDEX usergrp_grp ON usergrp (grp);

--
-- Table structure for table 'bounds'
--

CREATE TABLE bounds (
  boundsaddr bigint NOT NULL default '0',
  boundssize int NOT NULL default '0',
  grp varchar(40) NOT NULL default ''
);
CREATE INDEX bounds_grp ON bounds (grp);
CREATE INDEX bounds_boundsaddr ON bounds (boundsaddr);

